PropertySelector

Struct PropertySelector 

pub struct PropertySelector {
    pub node_path: Vec<StringSelector>,
    pub target_properties: StringSelector,
}
A selector defining a set of nodes to match, and on those matched nodes a set of named properties to match.

Fields

node_path: Vec<StringSelector>

A vector of StringSelectors which serve as a pattern matcher for paths through a hierarchy of named nodes. Each entry in the vector is a selector for a single named node in a data hierarchy. The vector of selectors for named nodes, then, defines a selector on paths through the data hierarchy.

Node paths support wildcarding, which will glob a single level of a node hierarchy. eg: root/a/b//d will match all nodes named d which are below some child of node b. root/a/b/c will match all nodes below b which start with the character “c”.

target_properties: StringSelector

A StringSelector which serves as a pattern matcher for string-named properties on a node in a data hierarchy.

target_properties supports wildcarding, which will match against all properties on any node matched by node_path.